# -*- coding: utf-8 -*-
# Generated by Django 1.9.8 on 2016-07-25 09:03
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='EmailConfirmation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('object_id', models.PositiveIntegerField()),
                ('email_field_name', models.CharField(default='email', max_length=32, verbose_name='Email field name')),
                ('email', models.EmailField(db_index=True, max_length=254, verbose_name='Email')),
                ('confirmation_key', models.CharField(max_length=64, unique=True, verbose_name='Confirmation_key')),
                ('send_at', models.DateTimeField(blank=True, db_index=True, null=True)),
                ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType')),
            ],
            options={
                'verbose_name': 'Email confirmation',
                'verbose_name_plural': 'Email confirmation',
            },
        ),
        migrations.AlterUniqueTogether(
            name='emailconfirmation',
            unique_together=set([('content_type', 'object_id', 'email_field_name')]),
        ),
    ]
